@@ -1,4 +1,4 @@
 library(testthat)
 library(bmp)
 
-test_package("bmp")
\ No newline at end of file
+test_check("bmp")
